num

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 26, 2023 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseBool added in v0.1.3

func ParseBool(val string) (bool, error)

ParseBool is a convenience function to parse a string into a bool

func ParseInt added in v0.1.3

func ParseInt(num string) (int, error)

ParseInt is a convenience function to parse a string into an int

func ParseInt32

func ParseInt32(num string) (int32, error)

ParseInt32 is a convenience function to parse a string into an int32

func ParseInt64

func ParseInt64(num string) (int64, error)

ParseInt64 is a convenience function to parse a string into an int64

func ParseUint added in v0.1.3

func ParseUint(num string) (uint, error)

ParseUint is a convenience function to parse a string into an uint

func ParseUint32

func ParseUint32(num string) (uint32, error)

ParseUint32 is a convenience function to parse a string into an uint32

func ParseUint64

func ParseUint64(num string) (uint64, error)

ParseUint64 is a convenience function to parse a string into an uint64

Types

This section is empty.

Jump to